==> SicoCreditPlus_v1.3.10.zip: SicoCreditPlus/CHANGELOG_de-DE.md <==
# 1.3.10
- Englische Texte endlich übersetzt
- Fortschritt auf "Antragsformular liegt dem Kunden vor" wirft jetzt keine Fehlermeldung mehr ins Log
- Text "Finanzierung abgebrochen" wird jetzt nicht mehr angezeigt, wenn die Bestellung und Finanzierung in Bearbeitung ist

# 1.3.9
- Bugfix für Filter, wenn "WARNING" als Exception geworfen wird
- API Prüfung bei Berechnung auf jeweiliges System geschickt
- Anzahl an Anfragen an WSDL Datei bei Objekt Erstellung reduziert
- Umstellung bei Transaktionsnummer und Bestellnummer

# 1.3.8
- Erweiterung um vorberechnete günstigste Rate für Exporte und Filter
  - Dieses Beispiel liegt auch in CodeBlocks.txt vor
```
{# Beispielcode für XML Export #}
{% if product.sicoCreditPlusCalculatedRates && product.sicoCreditPlusCalculatedRates|length > 0 %}
    {% for calcRate in product.sicoCreditPlusCalculatedRates %}
        <financing:available>true</financing:available>
        {% if calcRate.sicoAbsoluteMinRateMonths > -1 %}
            <financing:minRateText>Schon ab {{ calcRate.sicoAbsoluteMinRateRate|number_format(2,',','.') }} € für {{ calcRate.sicoAbsoluteMinRateMonths }} Monate finanzieren.</financing:minRateText>
        {% endif %}
    {% endfor %}
{% endif %}
```
- Neuer CronJob für die Berechnung der günstigsten Rate und Zurücksetzen der Berechnung (Muss einmalig gestartet werden)
- Filter für "Finanzierbar ab x Euro monatlich" eingebaut
- Bugfix zum Anlegen von CreditPlus Bestellungen durch Trigger Aufrufe
- Bugfix für Statusübergänge (Duplikate entfernt, fehlende hinzugefügt)
- Test Möglichkeit hinzugefügt durch Aktivieren des Test-Modus und setzen einer Bestellnummer und fixen CreditPlus-Status für die Bestellung
- "Jetzt Finanzieren" Button wird angezeigt, wenn die Zahlung in 3 zusätzlichen Zuständen ist

# 1.3.7
- Anlegen verlorener Informationen zu Bestellungen, wenn im Backend die Bestellung bearbeitet wurde
- Abhängigkeit von sico_credit_plus_payment zu order angepasst, damit keine weiteren Daten verloren gehen

# 1.3.6
- Absturz verhindern, wenn der Warenkorb nur mit nicht-Produkten gefüllt ist
- Ändern der Zahlungsart ist jetzt im Backend möglich
- "Versendet" Markierung bei Lieferungen stoßen Information zu CreditPlus an, steuerbar über Flow Builder 

# 1.3.5
- Fehler behoben, der bei Nutzung des Cronjobs zu dynamischen Produktgruppen auftrat, wenn Feeds als Verkaufskanäle angelegt sind
- Button zur Fortsetzung der Finanzierung auf der Account Übersicht und Bestellübersicht Seite etwas prominenter platziert

# 1.3.4
- Korrektur für Account Übersichtsseite, wenn die letzte Bestellung eine unvollendete CreditPlus Bestellung ist

# 1.3.3
- Fehler behoben, der bei einigen Einstellungen von dynamischen Produktgruppen auftrat
- Vorgebautes und unbenutztes Logging aus Scheduled Task entfernt
- Der Text über der Ratentabelle auf der Detailseite ist wieder da. Wenn man nur Leerzeichen nutzt, wird der Text samt umschließenden div nicht angezeigt.
- Standardwerte für productTypeID (7 -> 56) und productClassID (7 -> 11) bei frischen Installation geändert

# 1.3.2
- Dynamische Produktgruppen hinzugefügt (Produkte über Regeln zu CreditPlus Produktgruppen zuordnen, statt diese direkt zuzuweisen)
- Finanzierungskonditionen erhalten mehr Auswahlmöglichkeiten: "Teuerster Artikel im Warenkorb", "Größter Beitrag zum Warenkorb" und "Größte Anzahl im Warenkorb"
- Das Pop-Up für die Finanzierung schließt jetzt nur noch auf dem kleinen X 
- Die Darstellung auf Mobilgeräten für die Ratentabelle wurde behoben und etwas verschönert

# 1.3.1
- Speichern vor Ausleitung aus 6.4.x Version in 6.5.x Version übertragen
- Anpassung für ältere Migrations in neuere Doctrine Version
- Logging von Vorgängerversion wieder benutzbar machen (eigene Datei, eigene Level)
- CreditPlus Backend Ansicht von 6.4 auf 6.5 geupdatet.

# 1.3.0
- Mindestversion von 6.4.x auf 6.5.x angehoben

# 1.2.30
- Speichern von Bestellungen vor Ausleitung zur CreditPlus in eigenen Objekten
- Kleinere Tippfehler in Status "Entscheidung ausstehend" Mail angepasst

# 1.2.29
- CreditPlus Logo auf der Produkt-Karte auf der Kategorie Seite hinzugefügt

# 1.2.28
- Bugfix und Logging des Response Subscriber

# 1.2.27
- Einstellung "Anzeigen als" hat nun auch auswirkungen auf Account->Bestellungen->Jetzt Finanzieren Button
- Antragsstrecke bei Bestellungen, die die Antragsstrecke durchlaufen haben ist nicht mehr aufrufbar.
- Die Bestellung wird auf "Antrags gesehen" nur dann gesetzt, wenn die Bestellung im Open zustand ist.

# 1.2.26
- Statusmail wird jetzt auch bei Bestellungen in fremder Sprache korrekt verschickt.
- Fix: Stornierungsmail wird zwei mal versendet wenn die bestellung im Backend storniert wird

# 1.2.25
- Massives Performance Update bei Einsatz großer Listen für finanzierbare Artikel
- Einhängepunkt im Template von "page_checkout_finish_action" auf "page_checkout_finish_teaser" gewechselt (wegen deprecation durch Shopware)

# 1.2.24
- Andere Fehlermeldung bei "Vor Bestellabschluss" im iFrame zeigen

# 1.2.23
- Erlaubt die Anzeige von Fehlermeldungen ohne Angabe von Order Transaction IDs

# 1.2.22
- Iframe für X-Frame Options erlaubt
- Transaction ID erlaubt mit W-Nummer-DE und IDs mit "HzV25fg" und anderen Zeichen

# 1.2.21
- Status Mail Template: Update um die true/false Werte anzuzeigen
- Status Mail Template: Altes Update verbessert um die korrekte "plain" Datei zu nehmen

# 1.2.20
- Debug-only Version um Updates von Updates für Mails zu testen
- Status Mail Template: Template für Status Mails angepasst, damit diese mehr Informationen zu dem Vertrag beinhalten

# 1.2.19
- Bugfix: Duplizierung von Bestellungen durch Klicks im Frontend wird jetzt verhindert

# 1.2.18
- Das Plugin ist nun Multi Verkaufskanal fähig.

# 1.2.17
- Zahlstatus ist statt State Name im Feld Finanzierungsstatus sichtbar.

# 1.2.16
- Fix: Beim Neuinstallieren kann das Plugin nicht den index von order_id löschen

# 1.2.15
- Bugfix: Foreign Key Cascade Migrations Datei

# 1.2.14
- Die Ratentabelle kann nun wahlweise als tab oder als Modalbox angezeigt werden.

# 1.2.13
- Fix: Beim erneuten Installieren kam es zu einem Datenbankfehler

# 1.2.12
- Fix: Die Antragsstrecke kann bei einer stornierten Bestellung geöffnet werden.  

# 1.2.11
- Error auf der Confirm Seite gefixt. Dieser wurde durch den "nach Bestellabschluss" Modus und Warenkorb wert unterhalb der Finanzierungsgrenze ausgelößt

# 1.2.10
- Fehler beim Triggern der Statusänderung behoben

# 1.2.9
- Fix für überschriebene Session in Firefox
- nicht ordentlich gecheckte ordernumber gefixt
- Fix für Fehler im orderstatus, wenn die Seite in einer anderen Sprache als Deutsch oder Englisch angeschaut wird
- Fix "Can't drop sico_credit_plus_payment_ibfk_1" error beim Update des Plugins
- Mobile Ratentabelle wird wieder angezeigt.

# 1.2.8
- Bugfix für 404 Fehler, wenn die dispatch Route aufgerufen wird

# 1.2.7
- Fix: Bestandserhöhung nach Stornierung
- Vermeidung von doppelten Requests in den Bestelldetails
- Überflüssiger Request bei nicht CreditPlus bestellungen in den Bestelldetails vermieden 

# 1.2.6
- Aktualisierung der Verträge während des ladens der Bestell liste entfernt
- Button hinzugefügt für das Aktualisieren der Verträge der angezeigten Bestellungen
- Fix für den Reflection Error

# 1.2.5
- Textkonstanten mit Textbausteinen ersetzt
- CreditPlus Bestellungen zu löschen führt nun nicht mehr zum fehler
- Log einträge können nun in die Datenbank geschrieben werden
- Bugs behoben

# 1.2.4
- Decorator Pattern verursacht nicht mehr Probleme

# 1.2.3
- Texte angepasst
- Default Plugin Werte angepasst

# 1.2.2
- Fix Error wird angezeigt, wenn Antrag abgelehnt wird
- Texte im Bestellabschluss sind zentriert.

# 1.2.1
- Fix Chrome Cookie Bug
- Fix nach Bestellabschluss Fehler

# 1.2.0
- Plugin ist nun für 6.4 Bereit. Shopware 6.3 funktioniert nicht mehr zusammen mit dem Plugin

# 1.1.5
- Fix Gutschein Behandlung

# 1.1.4
- Bei Inorder Bestellungen werden die bestellungen im Backend nun richtig geupdated
- Fehlende Order Transitions hinzugefügt
- Fehler der durch Gutscheine ausgelöst wurde, wurde behoben.

# 1.1.3
- Bugfixing
- Der Benutzer bekommt keine "abgelehnt" E-Mails mehr, da CreditPlus diese verschickt

# 1.1.2
- Bugfixing
- Die Statusmail geht nun auch an den Kunden raus

# 1.1.1
- verschiedene Fehler behoben.

# 1.1.0
- Bei einer inorder Bestellung wird nun keine Bestellung mehr angelegt.

# 1.0.6
- Die Antragsstrecke kann nun innerhalb des Bestellprozesses angezeigt werden.

# 1.0.5
- Fehlermeldung durch Vue im Backend gefixt. Dadurch ist auch das Backend abgestürzt
- Anzahl der Bestellungen bei der Anfrage zum CreditPlus Server limitiert

# 1.0.4
- Fix 6.3.0.0+ Inhalt des Iframe wird nicht geladen.

# 1.0.3
- Fix: Anpassung für "InheritanceUpdater" für die Versionen 6.3.0.0+
- Fix: 6.2.x Fehler bei Rabatten im Warenkorb

# 1.0.2
- Fix: Eine Änderung an den "Monate" Input Feld der Zinsen führt dazu, dass der Datensatz nicht gespeichert wird
- Fix: Eine Änderung an den "Aktiv" Input Feld der Zinsen führt dazu, dass der Datensatz nicht gespeichert wird
- "Aktiv" Feld von Text Input auf Switch Feld geändert.
- In der Zinstabelle wird nun auch die Produktgruppe korrekt ausgegeben

# 1.0.1
- "Nach Bestellabschluss" Option im Zahlungszeitpunkt select box entfernt

# 1.0.0
- Erste Version des CreditPlus Plugins

==> SicoCreditPlus_v1.4.5.zip: SicoCreditPlus/CHANGELOG_de-DE.md <==
# 1.4.5
- Fehlerbehebung, wenn man 2 Bestellungen anfängt, aber nicht abschließt, um danach beide bei CreditPlus abzuschließen

# 1.4.4
- Einbau von Korrekturen aus 1.5.0 in 6.6.x Version
- Löschen von gespeicherten Bestellungen, wenn Umwandlung stattfindet
- Einbau von Titelzeile bei Select Boxen zu Bestellstatus
- Sortierung von Laufzeiten im Backend
- Speicherung neuer Raten im Backend speichert jetzt auch die Laufzeit direkt ab
- Ausschluss von Finanzierungen besser abgefragt (Session Problem behoben)
- Einen Schritt bei Zuweisungen von Gruppen umgestellt (funktioniert vor dem 6.7.x Update ebenso)

# 1.4.3
- Raten auch für Varianten berechnen (macht "finanzierbar" Filter für Varianten benutzbar)
- Korrektur in CodeBlocks.txt um beim Export "finanzierbar nein" ebenso aufzunehmen
- Entfernen der Zahlungsart aus 2 Subscribern in einen verschoben, der bessere Fehlermeldungen erlaubt

# 1.4.2
- Plugin activate service aktualisiert
- Deaktivierter Checkout-Button behoben, wenn andere Zahlungsart ausgewählt war und CreditPlus Bedingungen nicht erfüllt waren
- Fehler in einer Abfrage behoben, welcher beim Bestätigen vom Versand per Statuswechsel auftreten konnte
- Unbenutzte Klasse mit überflüssigen var_dumps entfernt
- Korrektur an automatischem Status Update, wenn "Nach Bestellabschluss" und "Bestellnummer als Transaktionsnummer" ausgewählt sind
- Korrektur für Trigger URLs aus Migration in Scheduled Task ausgelagert
- Neubau der Ratenberechnung von 1.3.8 in SQL Statements, da Shopware Objekte nicht wie beabsichtigt funktionierten
- Mobile Ratentabelle korrigiert (Danke an Balearis)

# 1.4.1
- Doppeltes Update von Statuswechseln entfernt
- Technischen Namen für die Zahlungsart hinzugefügt
- Updates nach 1.3.8 bis 1.3.10 aus 6.5.x Plugin aufgenommen

# 1.4.0
- Erweiterung auf Shopware 6.6.x und PHP 8.2+ angepasst
- Stand der Erweiterung ist ca. 1.3.8 aus 6.5.x Version

# 1.3.10
- Englische Texte endlich übersetzt
- Fortschritt auf "Antragsformular liegt dem Kunden vor" wirft jetzt keine Fehlermeldung mehr ins Log
- Text "Finanzierung abgebrochen" wird jetzt nicht mehr angezeigt, wenn die Bestellung und Finanzierung in Bearbeitung ist

# 1.3.9
- Bugfix für Filter, wenn "WARNING" als Exception geworfen wird
- API Prüfung bei Berechnung auf jeweiliges System geschickt
- Anzahl an Anfragen an WSDL Datei bei Objekt Erstellung reduziert
- Umstellung bei Transaktionsnummer und Bestellnummer

# 1.3.8.1
- Bugfix für Filter, wenn "WARNING" als Exception geworfen wird
- API Prüfung bei Berechnung auf jeweiliges System geschickt
- Anzahl an Anfragen an WSDL Datei bei Objekt Erstellung reduziert

# 1.3.8
- Erweiterung um vorberechnete günstigste Rate für Exporte und Filter
  - Dieses Beispiel liegt auch in CodeBlocks.txt vor
```
{# Beispielcode für XML Export #}
{% if product.sicoCreditPlusCalculatedRates && product.sicoCreditPlusCalculatedRates|length > 0 %}
    {% for calcRate in product.sicoCreditPlusCalculatedRates %}
        <financing:available>true</financing:available>
        {% if calcRate.sicoAbsoluteMinRateMonths > -1 %}
            <financing:minRateText>Schon ab {{ calcRate.sicoAbsoluteMinRateRate|number_format(2,',','.') }} € für {{ calcRate.sicoAbsoluteMinRateMonths }} Monate finanzieren.</financing:minRateText>
        {% endif %}
    {% endfor %}
{% endif %}
```
- Neuer CronJob für die Berechnung der günstigsten Rate und Zurücksetzen der Berechnung (Muss einmalig gestartet werden)
- Filter für "Finanzierbar ab x Euro monatlich" eingebaut
- Bugfix zum Anlegen von CreditPlus Bestellungen durch Trigger Aufrufe
- Bugfix für Statusübergänge (Duplikate entfernt, fehlende hinzugefügt)
- Test Möglichkeit hinzugefügt durch Aktivieren des Test-Modus und setzen einer Bestellnummer und fixen CreditPlus-Status für die Bestellung
- "Jetzt Finanzieren" Button wird angezeigt, wenn die Zahlung in 3 zusätzlichen Zuständen ist

# 1.3.7
- Anlegen verlorener Informationen zu Bestellungen, wenn im Backend die Bestellung bearbeitet wurde
- Abhängigkeit von sico_credit_plus_payment zu order angepasst, damit keine weiteren Daten verloren gehen

# 1.3.6
- Absturz verhindern, wenn der Warenkorb nur mit nicht-Produkten gefüllt ist
- Ändern der Zahlungsart ist jetzt im Backend möglich
- "Versendet" Markierung bei Lieferungen stoßen Information zu CreditPlus an, steuerbar über Flow Builder 

# 1.3.5
- Fehler behoben, der bei Nutzung des Cronjobs zu dynamischen Produktgruppen auftrat, wenn Feeds als Verkaufskanäle angelegt sind
- Button zur Fortsetzung der Finanzierung auf der Account Übersicht und Bestellübersicht Seite etwas prominenter platziert

# 1.3.4
- Korrektur für Account Übersichtsseite, wenn die letzte Bestellung eine unvollendete CreditPlus Bestellung ist

# 1.3.3
- Fehler behoben, der bei einigen Einstellungen von dynamischen Produktgruppen auftrat
- Vorgebautes und unbenutztes Logging aus Scheduled Task entfernt
- Der Text über der Ratentabelle auf der Detailseite ist wieder da. Wenn man nur Leerzeichen nutzt, wird der Text samt umschließenden div nicht angezeigt.
- Standardwerte für productTypeID (7 -> 56) und productClassID (7 -> 11) bei frischen Installation geändert

# 1.3.2
- Dynamische Produktgruppen hinzugefügt (Produkte über Regeln zu CreditPlus Produktgruppen zuordnen, statt diese direkt zuzuweisen)
- Finanzierungskonditionen erhalten mehr Auswahlmöglichkeiten: "Teuerster Artikel im Warenkorb", "Größter Beitrag zum Warenkorb" und "Größte Anzahl im Warenkorb"
- Das Pop-Up für die Finanzierung schließt jetzt nur noch auf dem kleinen X 
- Die Darstellung auf Mobilgeräten für die Ratentabelle wurde behoben und etwas verschönert

# 1.3.1
- Speichern vor Ausleitung aus 6.4.x Version in 6.5.x Version übertragen
- Anpassung für ältere Migrations in neuere Doctrine Version
- Logging von Vorgängerversion wieder benutzbar machen (eigene Datei, eigene Level)
- CreditPlus Backend Ansicht von 6.4 auf 6.5 geupdatet.

# 1.3.0
- Mindestversion von 6.4.x auf 6.5.x angehoben

# 1.2.30
- Speichern von Bestellungen vor Ausleitung zur CreditPlus in eigenen Objekten
- Kleinere Tippfehler in Status "Entscheidung ausstehend" Mail angepasst

# 1.2.29
- CreditPlus Logo auf der Produkt-Karte auf der Kategorie Seite hinzugefügt

# 1.2.28
- Bugfix und Logging des Response Subscriber

# 1.2.27
- Einstellung "Anzeigen als" hat nun auch auswirkungen auf Account->Bestellungen->Jetzt Finanzieren Button
- Antragsstrecke bei Bestellungen, die die Antragsstrecke durchlaufen haben ist nicht mehr aufrufbar.
- Die Bestellung wird auf "Antrags gesehen" nur dann gesetzt, wenn die Bestellung im Open zustand ist.

# 1.2.26
- Statusmail wird jetzt auch bei Bestellungen in fremder Sprache korrekt verschickt.
- Fix: Stornierungsmail wird zwei mal versendet wenn die bestellung im Backend storniert wird

# 1.2.25
- Massives Performance Update bei Einsatz großer Listen für finanzierbare Artikel
- Einhängepunkt im Template von "page_checkout_finish_action" auf "page_checkout_finish_teaser" gewechselt (wegen deprecation durch Shopware)

# 1.2.24
- Andere Fehlermeldung bei "Vor Bestellabschluss" im iFrame zeigen

# 1.2.23
- Erlaubt die Anzeige von Fehlermeldungen ohne Angabe von Order Transaction IDs

# 1.2.22
- Iframe für X-Frame Options erlaubt
- Transaction ID erlaubt mit W-Nummer-DE und IDs mit "HzV25fg" und anderen Zeichen

# 1.2.21
- Status Mail Template: Update um die true/false Werte anzuzeigen
- Status Mail Template: Altes Update verbessert um die korrekte "plain" Datei zu nehmen

# 1.2.20
- Debug-only Version um Updates von Updates für Mails zu testen
- Status Mail Template: Template für Status Mails angepasst, damit diese mehr Informationen zu dem Vertrag beinhalten

# 1.2.19
- Bugfix: Duplizierung von Bestellungen durch Klicks im Frontend wird jetzt verhindert

# 1.2.18
- Das Plugin ist nun Multi Verkaufskanal fähig.

# 1.2.17
- Zahlstatus ist statt State Name im Feld Finanzierungsstatus sichtbar.

# 1.2.16
- Fix: Beim Neuinstallieren kann das Plugin nicht den index von order_id löschen

# 1.2.15
- Bugfix: Foreign Key Cascade Migrations Datei

# 1.2.14
- Die Ratentabelle kann nun wahlweise als tab oder als Modalbox angezeigt werden.

# 1.2.13
- Fix: Beim erneuten Installieren kam es zu einem Datenbankfehler

# 1.2.12
- Fix: Die Antragsstrecke kann bei einer stornierten Bestellung geöffnet werden.  

# 1.2.11
- Error auf der Confirm Seite gefixt. Dieser wurde durch den "nach Bestellabschluss" Modus und Warenkorb wert unterhalb der Finanzierungsgrenze ausgelößt

# 1.2.10
- Fehler beim Triggern der Statusänderung behoben

# 1.2.9
- Fix für überschriebene Session in Firefox
- nicht ordentlich gecheckte ordernumber gefixt
- Fix für Fehler im orderstatus, wenn die Seite in einer anderen Sprache als Deutsch oder Englisch angeschaut wird
- Fix "Can't drop sico_credit_plus_payment_ibfk_1" error beim Update des Plugins
- Mobile Ratentabelle wird wieder angezeigt.

# 1.2.8
- Bugfix für 404 Fehler, wenn die dispatch Route aufgerufen wird

# 1.2.7
- Fix: Bestandserhöhung nach Stornierung
- Vermeidung von doppelten Requests in den Bestelldetails
- Überflüssiger Request bei nicht CreditPlus bestellungen in den Bestelldetails vermieden 

# 1.2.6
- Aktualisierung der Verträge während des ladens der Bestell liste entfernt
- Button hinzugefügt für das Aktualisieren der Verträge der angezeigten Bestellungen
- Fix für den Reflection Error

# 1.2.5
- Textkonstanten mit Textbausteinen ersetzt
- CreditPlus Bestellungen zu löschen führt nun nicht mehr zum fehler
- Log einträge können nun in die Datenbank geschrieben werden
- Bugs behoben

# 1.2.4
- Decorator Pattern verursacht nicht mehr Probleme

# 1.2.3
- Texte angepasst
- Default Plugin Werte angepasst

# 1.2.2
- Fix Error wird angezeigt, wenn Antrag abgelehnt wird
- Texte im Bestellabschluss sind zentriert.

# 1.2.1
- Fix Chrome Cookie Bug
- Fix nach Bestellabschluss Fehler

# 1.2.0
- Plugin ist nun für 6.4 Bereit. Shopware 6.3 funktioniert nicht mehr zusammen mit dem Plugin

# 1.1.5
- Fix Gutschein Behandlung

# 1.1.4
- Bei Inorder Bestellungen werden die bestellungen im Backend nun richtig geupdated
- Fehlende Order Transitions hinzugefügt
- Fehler der durch Gutscheine ausgelöst wurde, wurde behoben.

# 1.1.3
- Bugfixing
- Der Benutzer bekommt keine "abgelehnt" E-Mails mehr, da CreditPlus diese verschickt

# 1.1.2
- Bugfixing
- Die Statusmail geht nun auch an den Kunden raus

# 1.1.1
- verschiedene Fehler behoben.

# 1.1.0
- Bei einer inorder Bestellung wird nun keine Bestellung mehr angelegt.

# 1.0.6
- Die Antragsstrecke kann nun innerhalb des Bestellprozesses angezeigt werden.

# 1.0.5
- Fehlermeldung durch Vue im Backend gefixt. Dadurch ist auch das Backend abgestürzt
- Anzahl der Bestellungen bei der Anfrage zum CreditPlus Server limitiert

# 1.0.4
- Fix 6.3.0.0+ Inhalt des Iframe wird nicht geladen.

# 1.0.3
- Fix: Anpassung für "InheritanceUpdater" für die Versionen 6.3.0.0+
- Fix: 6.2.x Fehler bei Rabatten im Warenkorb

# 1.0.2
- Fix: Eine Änderung an den "Monate" Input Feld der Zinsen führt dazu, dass der Datensatz nicht gespeichert wird
- Fix: Eine Änderung an den "Aktiv" Input Feld der Zinsen führt dazu, dass der Datensatz nicht gespeichert wird
- "Aktiv" Feld von Text Input auf Switch Feld geändert.
- In der Zinstabelle wird nun auch die Produktgruppe korrekt ausgegeben

# 1.0.1
- "Nach Bestellabschluss" Option im Zahlungszeitpunkt select box entfernt

# 1.0.0
- Erste Version des CreditPlus Plugins
